# Table of Contents

- [dashboards-settings](<./dashboards-settings.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Dashboards Settings](<./Dashboards-Settings.md>)
  - [Overview](<./Dashboards-Settings/Overview.md>)
  - [Predefined Dashboards](<./Dashboards-Settings/Predefined-Dashboards.md>)
  - [Default Dashboard](<./Dashboards-Settings/Default-Dashboard.md>)
  - [External Content](<./Dashboards-Settings/External-Content.md>)
  - [Dashboard Templates](<./Dashboards-Settings/Dashboard-Templates.md>)
